@@ -28,7 +28,6 @@
 #include <gnutls_cipher_int.h>
 #include <gnutls_datum.h>
 #include <gnutls/crypto.h>
-#include <random.h>
 #include <crypto.h>
 
 /**
@@ -49,8 +48,8 @@
  **/
 int
 gnutls_cipher_init (gnutls_cipher_hd_t * handle,
-                    gnutls_cipher_algorithm_t cipher,
-                    const gnutls_datum_t * key, const gnutls_datum_t * iv)
+		    gnutls_cipher_algorithm_t cipher,
+		    const gnutls_datum_t * key, const gnutls_datum_t * iv)
 {
   *handle = gnutls_malloc (sizeof (cipher_hd_st));
   if (*handle == NULL)
@@ -62,74 +61,6 @@ gnutls_cipher_init (gnutls_cipher_hd_t * handle,
   return _gnutls_cipher_init (((cipher_hd_st *) * handle), cipher, key, iv);
 }
 
-/**
- * gnutls_cipher_tag:
- * @handle: is a #gnutls_cipher_hd_t structure.
- * @tag: will hold the tag
- * @tag_size: The length of the tag to return
- *
- * This function operates on authenticated encryption with
- * associated data (AEAD) ciphers and will return the
- * output tag.
- *
- * Returns: Zero or a negative value on error.
- *
- * Since: 2.99.0
- **/
-int
-gnutls_cipher_tag (gnutls_cipher_hd_t handle, void *tag, size_t tag_size)
-{
-  if (_gnutls_cipher_is_aead( (cipher_hd_st*)handle)==0)
-    return gnutls_assert_val(GNUTLS_E_INVALID_REQUEST);
-
-  _gnutls_cipher_tag( (cipher_hd_st*)handle, tag, tag_size);
-  
-  return 0;
-}
-
-/**
- * gnutls_cipher_add_auth:
- * @handle: is a #gnutls_cipher_hd_t structure.
- * @text: the data to be authenticated
- * @text_size: The length of the data
- *
- * This function operates on authenticated encryption with
- * associated data (AEAD) ciphers and authenticate the
- * input data. This function can only be called before
- * encryption operations.
- *
- * Returns: Zero or a negative value on error.
- *
- * Since: 2.99.0
- **/
-int
-gnutls_cipher_add_auth (gnutls_cipher_hd_t handle, const void *text, size_t text_size)
-{
-  if (_gnutls_cipher_is_aead( (cipher_hd_st*)handle)==0)
-    return gnutls_assert_val(GNUTLS_E_INVALID_REQUEST);
-
-  _gnutls_cipher_auth( (cipher_hd_st*)handle, text, text_size);
-  
-  return 0;
-}
-
-/**
- * gnutls_cipher_set_iv:
- * @handle: is a #gnutls_cipher_hd_t structure.
- * @iv: the IV to set
- * @ivlen: The length of the IV
- *
- * This function will set the IV to be used for the next
- * encryption block.
- *
- * Since: 2.99.0
- **/
-void
-gnutls_cipher_set_iv (gnutls_cipher_hd_t handle, void *iv, size_t ivlen)
-{
-  _gnutls_cipher_setiv((cipher_hd_st *)handle, iv, ivlen);
-}
-
 /**
  * gnutls_cipher_encrypt:
  * @handle: is a #gnutls_cipher_hd_t structure.
@@ -164,56 +95,10 @@ gnutls_cipher_encrypt (gnutls_cipher_hd_t handle, void *text, size_t textlen)
  **/
 int
 gnutls_cipher_decrypt (gnutls_cipher_hd_t handle, void *ciphertext,
-                       size_t ciphertextlen)
+		       size_t ciphertextlen)
 {
   return _gnutls_cipher_decrypt ((cipher_hd_st *) handle, ciphertext,
-                                 ciphertextlen);
-}
-
-/**
- * gnutls_cipher_encrypt2:
- * @handle: is a #gnutls_cipher_hd_t structure.
- * @text: the data to encrypt
- * @textlen: The length of data to encrypt
- * @ciphertext: the encrypted data
- * @ciphertextlen: The available length for encrypted data
- *
- * This function will encrypt the given data using the algorithm
- * specified by the context.
- *
- * Returns: Zero or a negative value on error.
- *
- * Since: 2.10.0
- **/
-int
-gnutls_cipher_encrypt2 (gnutls_cipher_hd_t handle, const void *text, size_t textlen,
-                        void *ciphertext, size_t ciphertextlen)
-{
-  return _gnutls_cipher_encrypt2 ((cipher_hd_st *) handle, text, textlen,
-                                  ciphertext, ciphertextlen);
-}
-
-/**
- * gnutls_cipher_decrypt2:
- * @handle: is a #gnutls_cipher_hd_t structure.
- * @ciphertext: the data to encrypt
- * @ciphertextlen: The length of data to encrypt
- * @text: the decrypted data
- * @textlen: The available length for decrypted data
- *
- * This function will decrypt the given data using the algorithm
- * specified by the context.
- *
- * Returns: Zero or a negative value on error.
- *
- * Since: 2.10.0
- **/
-int
-gnutls_cipher_decrypt2 (gnutls_cipher_hd_t handle, const void *ciphertext,
-                        size_t ciphertextlen, void *text, size_t textlen)
-{
-  return _gnutls_cipher_decrypt2 ((cipher_hd_st *) handle, ciphertext,
-                                  ciphertextlen, text, textlen);
+				 ciphertextlen);
 }
 
 /**
@@ -253,8 +138,8 @@ gnutls_cipher_deinit (gnutls_cipher_hd_t handle)
  **/
 int
 gnutls_hmac_init (gnutls_hmac_hd_t * dig,
-                  gnutls_digest_algorithm_t algorithm,
-                  const void *key, size_t keylen)
+		  gnutls_digest_algorithm_t algorithm,
+		  const void *key, size_t keylen)
 {
   *dig = gnutls_malloc (sizeof (digest_hd_st));
   if (*dig == NULL)
@@ -352,8 +237,8 @@ gnutls_hmac_get_len (gnutls_mac_algorithm_t algorithm)
  **/
 int
 gnutls_hmac_fast (gnutls_mac_algorithm_t algorithm,
-                  const void *key, size_t keylen,
-                  const void *text, size_t textlen, void *digest)
+		  const void *key, size_t keylen,
+		  const void *text, size_t textlen, void *digest)
 {
   return _gnutls_hmac_fast (algorithm, key, keylen, text, textlen, digest);
 }
@@ -471,44 +356,7 @@ gnutls_hash_get_len (gnutls_digest_algorithm_t algorithm)
  **/
 int
 gnutls_hash_fast (gnutls_digest_algorithm_t algorithm,
-                  const void *text, size_t textlen, void *digest)
+		  const void *text, size_t textlen, void *digest)
 {
   return _gnutls_hash_fast (algorithm, text, textlen, digest);
 }
-
-/**
- * gnutls_key_generate:
- * @key: is a pointer to a #gnutls_datum_t which will contain a newly
- * created key.
- * @key_size: The number of bytes of the key.
- *
- * Generates a random key of @key_bytes size.
- *
- * Returns: On success, %GNUTLS_E_SUCCESS (0) is returned, or an
- * error code.
- *
- * Since: 3.0.0
- **/
-int
-gnutls_key_generate (gnutls_datum_t * key, unsigned int key_size)
-{
-  int ret;
-
-  key->size = key_size;
-  key->data = gnutls_malloc (key->size);
-  if (!key->data)
-    {
-      gnutls_assert ();
-      return GNUTLS_E_MEMORY_ERROR;
-    }
-
-  ret = _gnutls_rnd (GNUTLS_RND_RANDOM, key->data, key->size);
-  if (ret < 0)
-    {
-      gnutls_assert ();
-      _gnutls_free_datum (key);
-      return ret;
-    }
-
-  return 0;
-}
