@@ -1,5 +1,5 @@
 /* Parse printf format string.
-   Copyright (C) 1999, 2002-2003, 2005, 2007, 2010-2011 Free Software
+   Copyright (C) 1999, 2002-2003, 2005, 2007, 2009-2010 Free Software
    Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
@@ -23,10 +23,6 @@
      ENABLE_UNISTDIO    Set to 1 to enable the unistdio extensions.
      STATIC             Set to 'static' to declare the function static.  */
 
-#if HAVE_FEATURES_H
-# include <features.h> /* for __GLIBC__, __UCLIBC__ */
-#endif
-
 #include "printf-args.h"
 
 
@@ -37,9 +33,6 @@
 #define FLAG_SPACE       8      /* space flag */
 #define FLAG_ALT        16      /* # flag */
 #define FLAG_ZERO       32
-#if __GLIBC__ >= 2 && !defined __UCLIBC__
-# define FLAG_LOCALIZED 64      /* I flag, uses localized digits */
-#endif
 
 /* arg_index value indicating that no argument is consumed.  */
 #define ARG_NONE        (~(size_t)0)
@@ -47,9 +40,6 @@
 /* xxx_directive: A parsed directive.
    xxx_directives: A parsed format string.  */
 
-/* Number of directly allocated directives (no malloc() needed).  */
-#define N_DIRECT_ALLOC_DIRECTIVES 7
-
 /* A parsed directive.  */
 typedef struct
 {
@@ -74,7 +64,6 @@ typedef struct
   char_directive *dir;
   size_t max_width_length;
   size_t max_precision_length;
-  char_directive direct_alloc_dir[N_DIRECT_ALLOC_DIRECTIVES];
 }
 char_directives;
 
@@ -104,7 +93,6 @@ typedef struct
   u8_directive *dir;
   size_t max_width_length;
   size_t max_precision_length;
-  u8_directive direct_alloc_dir[N_DIRECT_ALLOC_DIRECTIVES];
 }
 u8_directives;
 
@@ -132,7 +120,6 @@ typedef struct
   u16_directive *dir;
   size_t max_width_length;
   size_t max_precision_length;
-  u16_directive direct_alloc_dir[N_DIRECT_ALLOC_DIRECTIVES];
 }
 u16_directives;
 
@@ -160,7 +147,6 @@ typedef struct
   u32_directive *dir;
   size_t max_width_length;
   size_t max_precision_length;
-  u32_directive direct_alloc_dir[N_DIRECT_ALLOC_DIRECTIVES];
 }
 u32_directives;
 
