@@ -23,21 +23,19 @@
  *
  */
 
-#ifndef HANDSHAKE_H
-#define HANDSHAKE_H
-
 typedef enum Optional
-{ OPTIONAL_PACKET, MANDATORY_PACKET } optional_t;
+{ OPTIONAL_PACKET, MANDATORY_PACKET } Optional;
 
-int _gnutls_send_handshake (gnutls_session_t session, mbuffer_st * bufel,
-                            gnutls_handshake_description_t type);
+int _gnutls_send_handshake (gnutls_session_t session, void *i_data,
+			    uint32_t i_datasize,
+			    gnutls_handshake_description_t type);
 int _gnutls_recv_hello_request (gnutls_session_t session, void *data,
-                                uint32_t data_size);
+				uint32_t data_size);
 int _gnutls_send_hello (gnutls_session_t session, int again);
 int _gnutls_recv_hello (gnutls_session_t session, opaque * data, int datalen);
-int _gnutls_recv_handshake (gnutls_session_t session, 
-                        gnutls_handshake_description_t type,
-                        optional_t optional, gnutls_buffer_st* buf);
+int _gnutls_recv_handshake (gnutls_session_t session, uint8_t **, int *,
+			    gnutls_handshake_description_t,
+			    Optional optional);
 int _gnutls_generate_session_id (opaque * session_id, uint8_t * len);
 int _gnutls_handshake_common (gnutls_session_t session);
 int _gnutls_handshake_client (gnutls_session_t session);
@@ -46,17 +44,17 @@ void _gnutls_set_server_random (gnutls_session_t session, uint8_t * rnd);
 void _gnutls_set_client_random (gnutls_session_t session, uint8_t * rnd);
 int _gnutls_tls_create_random (opaque * dst);
 int _gnutls_remove_unwanted_ciphersuites (gnutls_session_t session,
-                                          cipher_suite_st ** cipherSuites,
-                                          int numCipherSuites,
-                                          gnutls_pk_algorithm_t);
+					  cipher_suite_st ** cipherSuites,
+					  int numCipherSuites,
+					  gnutls_pk_algorithm_t);
 int _gnutls_find_pk_algos_in_ciphersuites (opaque * data, int datalen);
 int _gnutls_server_select_suite (gnutls_session_t session, opaque * data,
-                                 int datalen);
+				 int datalen);
 
 int _gnutls_negotiate_version (gnutls_session_t session,
-                               gnutls_protocol_t adv_version);
+			       gnutls_protocol_t adv_version);
 int _gnutls_user_hello_func (gnutls_session_t session,
-                             gnutls_protocol_t adv_version);
+			     gnutls_protocol_t adv_version);
 
 void _gnutls_handshake_hash_buffers_clear (gnutls_session_t session);
 
@@ -64,7 +62,4 @@ void _gnutls_handshake_hash_buffers_clear (gnutls_session_t session);
 /* This returns true if we have got there
  * before (and not finished due to an interrupt).
  */
-#define AGAIN(target) (STATE==target?1:0)
-#define AGAIN2(state, target) (state==target?1:0)
-
-#endif
+#define AGAIN(target) STATE==target?1:0
