@@ -24,7 +24,7 @@
  */
 
 #ifndef GNUTLS_NUM_H
-#define GNUTLS_NUM_H
+# define GNUTLS_NUM_H
 
 #include <gnutls_int.h>
 
@@ -32,7 +32,6 @@
 
 uint32_t _gnutls_uint24touint32 (uint24 num);
 uint24 _gnutls_uint32touint24 (uint32_t num);
-uint64_t _gnutls_read_uint48 (const opaque * data);
 uint32_t _gnutls_read_uint32 (const opaque * data);
 uint16_t _gnutls_read_uint16 (const opaque * data);
 uint32_t _gnutls_conv_uint32 (uint32_t data);
@@ -44,8 +43,7 @@ void _gnutls_write_uint16 (uint16_t num, opaque * data);
 uint32_t _gnutls_uint64touint32 (const uint64 *);
 
 int _gnutls_uint64pp (uint64 *);
-int _gnutls_uint48pp (uint64 *);
-
-# define UINT64DATA(x) ((x).i)
+# define _gnutls_uint64zero(x) x.i[0] = x.i[1] = x.i[2] = x.i[3] = x.i[4] = x.i[5] = x.i[6] = x.i[7] = 0
+# define UINT64DATA(x) x.i
 
 #endif /* GNUTLS_NUM_H */
